{ pkgs, ... }: {
  xdg.portal = {
    enable = true;
    #wlr.enable = true;
    xdgOpenUsePortal = true;
    extraPortals = with pkgs; [
      xdg-desktop-portal-hyprland
      xdg-desktop-portal-gtk
    ];
  };

  # Enable automatic login for the user.
  services = {
    # flatpak dev.deedles.Trayscale
    # sudo tailscale up --operator=$USER 
    # use https://hs.wetofu.me
    tailscale.enable = true;
    blueman.enable = true;
    logrotate.checkConfig = false;
    flatpak.enable = true;

    ntp = {
      enable = true;
      servers = [
        "ntp.ntsc.ac.cn" # China
      ];
    };

    greetd = {
      enable = true;
      settings = rec {
        initial_session = {
          user = "user";
          command = "${pkgs.greetd.greetd}/bin/agreety --cmd Hyprland";
        };
        default_session = initial_session;
      };
    };

    xserver = {
      layout = "cn";
      xkbVariant = "";
      libinput = {
        mouse = {
          accelProfile = "flat";
        };
      };
    };

    pipewire = {
      enable = true;
      alsa.enable = true;
      pulse.enable = true;
    };

    keyd = {
      enable = false;
      settings = {
        main = {
          capslock = "C-space";
        };
      };
    };

    upower = {
      enable = true;
      criticalPowerAction = "Hibernate";
    };
  };

  # List packages installed in system profile. To search, run:
  # $ nix search wget
  environment.systemPackages = with pkgs; [
    hyprpaper
    hyprland-protocols
    hyprland-share-picker
  ];

  programs = {
    hyprland = {
      enable = true;
      xwayland = {
        enable = true;
        hidpi = true;
      };
    };

    proxychains = {
      enable = true;
      quietMode = true;
      proxies = {
        default = {
          type = "socks5";
          port = 1089;
          host = "127.0.0.1";
          enable = true;
        };
      };
    };

    git.enable = true;
    zsh.enable = true;
    light.enable = true;
    dconf.enable = true;
  };
}
